{-# OPTIONS -Wall #-}

--------------------------------------------------------------------------------
-- |
-- Module      :  ColourDefns
-- Copyright   :  (c) Stephen Tetley 2009
-- License     :  BSD3
--
-- Maintainer  :  Stephen Tetley <stephen.tetley@gmail.com>
-- Stability   :  highly unstable
-- Portability :  GHC with TypeFamilies and more
--
-- All the SVG / X11 \"named colours\" listed in tables. 
--
--------------------------------------------------------------------------------

module ColourDefns
  ( 
  -- * Tables of all colours
    all_x11_colours
  , all_svg_colours

  ) where

import qualified Wumpus.Basic.SVGColours        as SVG
import qualified Wumpus.Basic.X11Colours        as X11

import Wumpus.Core.Colour ( DRGB )


all_svg_colours :: [(String,DRGB)]
all_svg_colours = 
  [ ("aliceBlue",               SVG.aliceBlue)
  , ("antiqueWhite",            SVG.antiqueWhite)
  , ("aqua",                    SVG.aqua)
  , ("aquamarine",              SVG.aquamarine)
  , ("azure",                   SVG.azure)
  , ("beige",                   SVG.beige)
  , ("bisque",                  SVG.bisque)
  , ("black",                   SVG.black)
  , ("blanchedAlmond",          SVG.blanchedAlmond)
  , ("blue",                    SVG.blue)
  , ("blueViolet",              SVG.blueViolet)
  , ("brown",                   SVG.brown)
  , ("burlywood",               SVG.burlywood)
  , ("cadetBlue",               SVG.cadetBlue)
  , ("chartreuse",              SVG.chartreuse)
  , ("chocolate",               SVG.chocolate)
  , ("coral",                   SVG.coral)
  , ("cornflowerBlue",          SVG.cornflowerBlue)
  , ("cornsilk",                SVG.cornsilk)
  , ("crimson",                 SVG.crimson)
  , ("cyan",                    SVG.cyan)
  , ("darkBlue",                SVG.darkBlue)
  , ("darkCyan",                SVG.darkCyan)
  , ("darkGoldenrod",           SVG.darkGoldenrod)
  , ("darkGray",                SVG.darkGray)
  , ("darkGreen",               SVG.darkGreen)
  , ("darkGrey",                SVG.darkGrey)
  , ("darkKhaki",               SVG.darkKhaki)
  , ("darkMagenta",             SVG.darkMagenta)
  , ("darkOliveGreen",          SVG.darkOliveGreen)
  , ("darkOrange",              SVG.darkOrange)
  , ("darkOrchid",              SVG.darkOrchid)
  , ("darkRed",                 SVG.darkRed)
  , ("darkSalmon",              SVG.darkSalmon)
  , ("darkSeaGreen",            SVG.darkSeaGreen)
  , ("darkSlateBlue",           SVG.darkSlateBlue)
  , ("darkSlateGray",           SVG.darkSlateGray)
  , ("darkSlateGrey",           SVG.darkSlateGrey)
  , ("darkTurquoise",           SVG.darkTurquoise)
  , ("darkViolet",              SVG.darkViolet)
  , ("deepPink",                SVG.deepPink)
  , ("deepSkyBlue",             SVG.deepSkyBlue)
  , ("dimGray",                 SVG.dimGray)
  , ("dimGrey",                 SVG.dimGrey)
  , ("dodgerBlue",              SVG.dodgerBlue)
  , ("firebrick",               SVG.firebrick)
  , ("floralWhite",             SVG.floralWhite)
  , ("forestGreen",             SVG.forestGreen)
  , ("fuchsia",                 SVG.fuchsia)
  , ("gainsboro",               SVG.gainsboro)
  , ("ghostWhite",              SVG.ghostWhite)
  , ("gold",                    SVG.gold)
  , ("goldenrod",               SVG.goldenrod)
  , ("gray",                    SVG.gray)
  , ("grey",                    SVG.grey)
  , ("green",                   SVG.green)
  , ("greenYellow",             SVG.greenYellow)
  , ("honeydew",                SVG.honeydew)
  , ("hotPink",                 SVG.hotPink)
  , ("indianRed",               SVG.indianRed)
  , ("indigo",                  SVG.indigo)
  , ("ivory",                   SVG.ivory)
  , ("khaki",                   SVG.khaki)
  , ("lavender",                SVG.lavender)
  , ("lavenderBlush",           SVG.lavenderBlush)
  , ("lawnGreen",               SVG.lawnGreen)
  , ("lemonChiffon",            SVG.lemonChiffon)
  , ("lightBlue",               SVG.lightBlue)
  , ("lightCoral",              SVG.lightCoral)
  , ("lightCyan",               SVG.lightCyan)
  , ("lightGoldenrodYellow",    SVG.lightGoldenrodYellow)
  , ("lightGray",               SVG.lightGray)
  , ("lightGreen",              SVG.lightGreen)
  , ("lightGrey",               SVG.lightGrey)
  , ("lightPink",               SVG.lightPink)
  , ("lightSalmon",             SVG.lightSalmon)
  , ("lightSeaGreen",           SVG.lightSeaGreen)
  , ("lightSkyBlue",            SVG.lightSkyBlue)
  , ("lightSlateGray",          SVG.lightSlateGray)
  , ("lightSlateGrey",          SVG.lightSlateGrey)
  , ("lightSteelBlue",          SVG.lightSteelBlue)
  , ("lightYellow",             SVG.lightYellow)
  , ("lime",                    SVG.lime)
  , ("limeGreen",               SVG.limeGreen)
  , ("linen",                   SVG.linen)
  , ("magenta",                 SVG.magenta)
  , ("maroon",                  SVG.maroon)
  , ("mediumAquamarine",        SVG.mediumAquamarine)
  , ("mediumBlue",              SVG.mediumBlue)
  , ("mediumOrchid",            SVG.mediumOrchid)
  , ("mediumPurple",            SVG.mediumPurple)
  , ("mediumSeaGreen",          SVG.mediumSeaGreen)
  , ("mediumSlateBlue",         SVG.mediumSlateBlue)
  , ("mediumSpringGreen",       SVG.mediumSpringGreen)
  , ("mediumTurquoise",         SVG.mediumTurquoise)
  , ("mediumVioletRed",         SVG.mediumVioletRed)
  , ("midnightBlue",            SVG.midnightBlue)
  , ("mintcream",               SVG.mintcream)
  , ("mistyrose",               SVG.mistyrose)
  , ("moccasin",                SVG.moccasin)
  , ("navajoWhite",             SVG.navajoWhite)
  , ("navy",                    SVG.navy)
  , ("oldlace",                 SVG.oldlace)
  , ("olive",                   SVG.olive)
  , ("oliveDrab",               SVG.oliveDrab)
  , ("orange",                  SVG.orange)
  , ("orangeRed",               SVG.orangeRed)
  , ("orchid",                  SVG.orchid)
  , ("paleGoldenrod",           SVG.paleGoldenrod)
  , ("paleGreen",               SVG.paleGreen)
  , ("paleTurquoise",           SVG.paleTurquoise)
  , ("paleVioletRed",           SVG.paleVioletRed)
  , ("papayawhip",              SVG.papayawhip)
  , ("peachpuff",               SVG.peachpuff)
  , ("peru",                    SVG.peru)
  , ("pink",                    SVG.pink)
  , ("plum",                    SVG.plum)
  , ("powderBlue",              SVG.powderBlue)
  , ("purple",                  SVG.purple)
  , ("red",                     SVG.red)
  , ("rosyBrown",               SVG.rosyBrown)
  , ("royalBlue",               SVG.royalBlue)
  , ("saddleBrown",             SVG.saddleBrown)
  , ("salmon",                  SVG.salmon)
  , ("sandyBrown",              SVG.sandyBrown)
  , ("seaGreen",                SVG.seaGreen)
  , ("seashell",                SVG.seashell)
  , ("sienna",                  SVG.sienna)
  , ("silver",                  SVG.silver)
  , ("skyBlue",                 SVG.skyBlue)
  , ("slateBlue",               SVG.slateBlue)
  , ("slateGray",               SVG.slateGray)
  , ("slateGrey",               SVG.slateGrey)
  , ("snow",                    SVG.snow)
  , ("springGreen",             SVG.springGreen)
  , ("steelBlue",               SVG.steelBlue)
  , ("tan",                     SVG.tan)
  , ("teal",                    SVG.teal)
  , ("thistle",                 SVG.thistle)
  , ("tomato",                  SVG.tomato)
  , ("turquoise",               SVG.turquoise)
  , ("violet",                  SVG.violet)
  , ("wheat",                   SVG.wheat)
  , ("white",                   SVG.white)
  , ("whitesmoke",              SVG.whitesmoke)
  , ("yellow",                  SVG.yellow)
  , ("yellowGreen",             SVG.yellowGreen)
  ]



all_x11_colours :: [(String,DRGB)]
all_x11_colours = 
  [ ("antiqueWhite1",           X11.antiqueWhite1)
  , ("antiqueWhite2",           X11.antiqueWhite2)
  , ("antiqueWhite3",           X11.antiqueWhite3)
  , ("antiqueWhite4",           X11.antiqueWhite4)
  , ("aquamarine1",             X11.aquamarine1)
  , ("aquamarine2",             X11.aquamarine2)
  , ("aquamarine3",             X11.aquamarine3)
  , ("aquamarine4",             X11.aquamarine4)
  , ("azure1",                  X11.azure1)
  , ("azure2",                  X11.azure2)
  , ("azure3",                  X11.azure3)
  , ("azure4",                  X11.azure4)
  , ("bisque1",                 X11.bisque1)
  , ("bisque2",                 X11.bisque2)
  , ("bisque3",                 X11.bisque3)
  , ("bisque4",                 X11.bisque4)
  , ("blue1",                   X11.blue1)
  , ("blue2",                   X11.blue2)
  , ("blue3",                   X11.blue3)
  , ("blue4",                   X11.blue4)
  , ("brown1",                  X11.brown1)
  , ("brown2",                  X11.brown2)
  , ("brown3",                  X11.brown3)
  , ("brown4",                  X11.brown4)
  , ("burlywood1",              X11.burlywood1)
  , ("burlywood2",              X11.burlywood2)
  , ("burlywood3",              X11.burlywood3)
  , ("burlywood4",              X11.burlywood4)
  , ("cadetBlue1",              X11.cadetBlue1)
  , ("cadetBlue2",              X11.cadetBlue2)
  , ("cadetBlue3",              X11.cadetBlue3)
  , ("cadetBlue4",              X11.cadetBlue4)
  , ("chartreuse1",             X11.chartreuse1)
  , ("chartreuse2",             X11.chartreuse2)
  , ("chartreuse3",             X11.chartreuse3)
  , ("chartreuse4",             X11.chartreuse4)
  , ("chocolate1",              X11.chocolate1)
  , ("chocolate2",              X11.chocolate2)
  , ("chocolate3",              X11.chocolate3)
  , ("chocolate4",              X11.chocolate4)
  , ("coral1",                  X11.coral1)
  , ("coral2",                  X11.coral2)
  , ("coral3",                  X11.coral3)
  , ("coral4",                  X11.coral4)
  , ("cornsilk1",               X11.cornsilk1)
  , ("cornsilk2",               X11.cornsilk2)
  , ("cornsilk3",               X11.cornsilk3)
  , ("cornsilk4",               X11.cornsilk4)
  , ("cyan1",                   X11.cyan1)
  , ("cyan2",                   X11.cyan2)
  , ("cyan3",                   X11.cyan3)
  , ("cyan4",                   X11.cyan4)
  , ("darkGoldenrod1",          X11.darkGoldenrod1)
  , ("darkGoldenrod2",          X11.darkGoldenrod2)
  , ("darkGoldenrod3",          X11.darkGoldenrod3)
  , ("darkGoldenrod4",          X11.darkGoldenrod4)
  , ("darkOliveGreen1",         X11.darkOliveGreen1)
  , ("darkOliveGreen2",         X11.darkOliveGreen2)
  , ("darkOliveGreen3",         X11.darkOliveGreen3)
  , ("darkOliveGreen4",         X11.darkOliveGreen4)
  , ("darkOrange1",             X11.darkOrange1)
  , ("darkOrange2",             X11.darkOrange2)
  , ("darkOrange3",             X11.darkOrange3)
  , ("darkOrange4",             X11.darkOrange4)
  , ("darkOrchid1",             X11.darkOrchid1)
  , ("darkOrchid2",             X11.darkOrchid2)
  , ("darkOrchid3",             X11.darkOrchid3)
  , ("darkOrchid4",             X11.darkOrchid4)
  , ("darkSeaGreen1",           X11.darkSeaGreen1)
  , ("darkSeaGreen2",           X11.darkSeaGreen2)
  , ("darkSeaGreen3",           X11.darkSeaGreen3)
  , ("darkSeaGreen4",           X11.darkSeaGreen4)
  , ("darkSlateGray1",          X11.darkSlateGray1)
  , ("darkSlateGray2",          X11.darkSlateGray2)
  , ("darkSlateGray3",          X11.darkSlateGray3)
  , ("darkSlateGray4",          X11.darkSlateGray4)
  , ("deepPink1",               X11.deepPink1)
  , ("deepPink2",               X11.deepPink2)
  , ("deepPink3",               X11.deepPink3)
  , ("deepPink4",               X11.deepPink4)
  , ("deepSkyBlue1",            X11.deepSkyBlue1)
  , ("deepSkyBlue2",            X11.deepSkyBlue2)
  , ("deepSkyBlue3",            X11.deepSkyBlue3)
  , ("deepSkyBlue4",            X11.deepSkyBlue4)
  , ("dodgerBlue1",             X11.dodgerBlue1)
  , ("dodgerBlue2",             X11.dodgerBlue2)
  , ("dodgerBlue3",             X11.dodgerBlue3)
  , ("dodgerBlue4",             X11.dodgerBlue4)
  , ("firebrick1",              X11.firebrick1)
  , ("firebrick2",              X11.firebrick2)
  , ("firebrick3",              X11.firebrick3)
  , ("firebrick4",              X11.firebrick4)
  , ("gold1",                   X11.gold1)
  , ("gold2",                   X11.gold2)
  , ("gold3",                   X11.gold3)
  , ("gold4",                   X11.gold4)
  , ("goldenrod1",              X11.goldenrod1)
  , ("goldenrod2",              X11.goldenrod2)
  , ("goldenrod3",              X11.goldenrod3)
  , ("goldenrod4",              X11.goldenrod4)
  , ("green1",                  X11.green1)
  , ("green2",                  X11.green2)
  , ("green3",                  X11.green3)
  , ("green4",                  X11.green4)
  , ("honeydew1",               X11.honeydew1)
  , ("honeydew2",               X11.honeydew2)
  , ("honeydew3",               X11.honeydew3)
  , ("honeydew4",               X11.honeydew4)
  , ("hotPink1",                X11.hotPink1)
  , ("hotPink2",                X11.hotPink2)
  , ("hotPink3",                X11.hotPink3)
  , ("hotPink4",                X11.hotPink4)
  , ("indianRed1",              X11.indianRed1)
  , ("indianRed2",              X11.indianRed2)
  , ("indianRed3",              X11.indianRed3)
  , ("indianRed4",              X11.indianRed4)
  , ("ivory1",                  X11.ivory1)
  , ("ivory2",                  X11.ivory2)
  , ("ivory3",                  X11.ivory3)
  , ("ivory4",                  X11.ivory4)
  , ("khaki1",                  X11.khaki1)
  , ("khaki2",                  X11.khaki2)
  , ("khaki3",                  X11.khaki3)
  , ("khaki4",                  X11.khaki4)
  , ("lavenderBlush1",          X11.lavenderBlush1)
  , ("lavenderBlush2",          X11.lavenderBlush2)
  , ("lavenderBlush3",          X11.lavenderBlush3)
  , ("lavenderBlush4",          X11.lavenderBlush4)
  , ("lemonChiffon1",           X11.lemonChiffon1)
  , ("lemonChiffon2",           X11.lemonChiffon2)
  , ("lemonChiffon3",           X11.lemonChiffon3)
  , ("lemonChiffon4",           X11.lemonChiffon4)
  , ("lightBlue1",              X11.lightBlue1)
  , ("lightBlue2",              X11.lightBlue2)
  , ("lightBlue3",              X11.lightBlue3)
  , ("lightBlue4",              X11.lightBlue4)
  , ("lightCyan1",              X11.lightCyan1)
  , ("lightCyan2",              X11.lightCyan2)
  , ("lightCyan3",              X11.lightCyan3)
  , ("lightCyan4",              X11.lightCyan4)
  , ("lightGoldenrod1",         X11.lightGoldenrod1)
  , ("lightGoldenrod2",         X11.lightGoldenrod2)
  , ("lightGoldenrod3",         X11.lightGoldenrod3)
  , ("lightGoldenrod4",         X11.lightGoldenrod4)
  , ("lightPink1",              X11.lightPink1)
  , ("lightPink2",              X11.lightPink2)
  , ("lightPink3",              X11.lightPink3)
  , ("lightPink4",              X11.lightPink4)
  , ("lightSalmon1",            X11.lightSalmon1)
  , ("lightSalmon2",            X11.lightSalmon2)
  , ("lightSalmon3",            X11.lightSalmon3)
  , ("lightSalmon4",            X11.lightSalmon4)
  , ("lightSkyBlue1",           X11.lightSkyBlue1)
  , ("lightSkyBlue2",           X11.lightSkyBlue2)
  , ("lightSkyBlue3",           X11.lightSkyBlue3)
  , ("lightSkyBlue4",           X11.lightSkyBlue4)
  , ("lightSteelBlue1",         X11.lightSteelBlue1)
  , ("lightSteelBlue2",         X11.lightSteelBlue2)
  , ("lightSteelBlue3",         X11.lightSteelBlue3)
  , ("lightSteelBlue4",         X11.lightSteelBlue4)
  , ("lightYellow1",            X11.lightYellow1)
  , ("lightYellow2",            X11.lightYellow2)
  , ("lightYellow3",            X11.lightYellow3)
  , ("lightYellow4",            X11.lightYellow4)
  , ("magenta1",                X11.magenta1)
  , ("magenta2",                X11.magenta2)
  , ("magenta3",                X11.magenta3)
  , ("magenta4",                X11.magenta4)
  , ("maroon1",                 X11.maroon1)
  , ("maroon2",                 X11.maroon2)
  , ("maroon3",                 X11.maroon3)
  , ("maroon4",                 X11.maroon4)
  , ("mediumOrchid1",           X11.mediumOrchid1)
  , ("mediumOrchid2",           X11.mediumOrchid2)
  , ("mediumOrchid3",           X11.mediumOrchid3)
  , ("mediumOrchid4",           X11.mediumOrchid4)
  , ("mediumPurple1",           X11.mediumPurple1)
  , ("mediumPurple2",           X11.mediumPurple2)
  , ("mediumPurple3",           X11.mediumPurple3)
  , ("mediumPurple4",           X11.mediumPurple4)
  , ("mistyRose1",              X11.mistyRose1)
  , ("mistyRose2",              X11.mistyRose2)
  , ("mistyRose3",              X11.mistyRose3)
  , ("mistyRose4",              X11.mistyRose4)
  , ("navajoWhite1",            X11.navajoWhite1)
  , ("navajoWhite2",            X11.navajoWhite2)
  , ("navajoWhite3",            X11.navajoWhite3)
  , ("navajoWhite4",            X11.navajoWhite4)
  , ("oliveDrab1",              X11.oliveDrab1)
  , ("oliveDrab2",              X11.oliveDrab2)
  , ("oliveDrab3",              X11.oliveDrab3)
  , ("oliveDrab4",              X11.oliveDrab4)
  , ("orange1",                 X11.orange1)
  , ("orange2",                 X11.orange2)
  , ("orange3",                 X11.orange3)
  , ("orange4",                 X11.orange4)
  , ("orangeRed1",              X11.orangeRed1)
  , ("orangeRed2",              X11.orangeRed2)
  , ("orangeRed3",              X11.orangeRed3)
  , ("orangeRed4",              X11.orangeRed4)
  , ("orchid1",                 X11.orchid1)
  , ("orchid2",                 X11.orchid2)
  , ("orchid3",                 X11.orchid3)
  , ("orchid4",                 X11.orchid4)
  , ("paleGreen1",              X11.paleGreen1)
  , ("paleGreen2",              X11.paleGreen2)
  , ("paleGreen3",              X11.paleGreen3)
  , ("paleGreen4",              X11.paleGreen4)
  , ("paleTurquoise1",          X11.paleTurquoise1)
  , ("paleTurquoise2",          X11.paleTurquoise2)
  , ("paleTurquoise3",          X11.paleTurquoise3)
  , ("paleTurquoise4",          X11.paleTurquoise4)
  , ("paleVioletRed1",          X11.paleVioletRed1)
  , ("paleVioletRed2",          X11.paleVioletRed2)
  , ("paleVioletRed3",          X11.paleVioletRed3)
  , ("paleVioletRed4",          X11.paleVioletRed4)
  , ("peachPuff1",              X11.peachPuff1)
  , ("peachPuff2",              X11.peachPuff2)
  , ("peachPuff3",              X11.peachPuff3)
  , ("peachPuff4",              X11.peachPuff4)
  , ("pink1",                   X11.pink1)
  , ("pink2",                   X11.pink2)
  , ("pink3",                   X11.pink3)
  , ("pink4",                   X11.pink4)
  , ("plum1",                   X11.plum1)
  , ("plum2",                   X11.plum2)
  , ("plum3",                   X11.plum3)
  , ("plum4",                   X11.plum4)
  , ("purple1",                 X11.purple1)
  , ("purple2",                 X11.purple2)
  , ("purple3",                 X11.purple3)
  , ("purple4",                 X11.purple4)
  , ("red1",                    X11.red1)
  , ("red2",                    X11.red2)
  , ("red3",                    X11.red3)
  , ("red4",                    X11.red4)
  , ("rosyBrown1",              X11.rosyBrown1)
  , ("rosyBrown2",              X11.rosyBrown2)
  , ("rosyBrown3",              X11.rosyBrown3)
  , ("rosyBrown4",              X11.rosyBrown4)
  , ("royalBlue1",              X11.royalBlue1)
  , ("royalBlue2",              X11.royalBlue2)
  , ("royalBlue3",              X11.royalBlue3)
  , ("royalBlue4",              X11.royalBlue4)
  , ("salmon1",                 X11.salmon1)
  , ("salmon2",                 X11.salmon2)
  , ("salmon3",                 X11.salmon3)
  , ("salmon4",                 X11.salmon4)
  , ("seaGreen1",               X11.seaGreen1)
  , ("seaGreen2",               X11.seaGreen2)
  , ("seaGreen3",               X11.seaGreen3)
  , ("seaGreen4",               X11.seaGreen4)
  , ("seashell1",               X11.seashell1)
  , ("seashell2",               X11.seashell2)
  , ("seashell3",               X11.seashell3)
  , ("seashell4",               X11.seashell4)
  , ("sienna1",                 X11.sienna1)
  , ("sienna2",                 X11.sienna2)
  , ("sienna3",                 X11.sienna3)
  , ("sienna4",                 X11.sienna4)
  , ("skyBlue1",                X11.skyBlue1)
  , ("skyBlue2",                X11.skyBlue2)
  , ("skyBlue3",                X11.skyBlue3)
  , ("skyBlue4",                X11.skyBlue4)
  , ("slateBlue1",              X11.slateBlue1)
  , ("slateBlue2",              X11.slateBlue2)
  , ("slateBlue3",              X11.slateBlue3)
  , ("slateBlue4",              X11.slateBlue4)
  , ("slateGray1",              X11.slateGray1)
  , ("slateGray2",              X11.slateGray2)
  , ("slateGray3",              X11.slateGray3)
  , ("slateGray4",              X11.slateGray4)
  , ("snow1",                   X11.snow1)
  , ("snow2",                   X11.snow2)
  , ("snow3",                   X11.snow3)
  , ("snow4",                   X11.snow4)
  , ("springGreen1",            X11.springGreen1)
  , ("springGreen2",            X11.springGreen2)
  , ("springGreen3",            X11.springGreen3)
  , ("springGreen4",            X11.springGreen4)
  , ("steelBlue1",              X11.steelBlue1)
  , ("steelBlue2",              X11.steelBlue2)
  , ("steelBlue3",              X11.steelBlue3)
  , ("steelBlue4",              X11.steelBlue4)
  , ("tan1",                    X11.tan1)
  , ("tan2",                    X11.tan2)
  , ("tan3",                    X11.tan3)
  , ("tan4",                    X11.tan4)
  , ("thistle1",                X11.thistle1)
  , ("thistle2",                X11.thistle2)
  , ("thistle3",                X11.thistle3)
  , ("thistle4",                X11.thistle4)
  , ("tomato1",                 X11.tomato1)
  , ("tomato2",                 X11.tomato2)
  , ("tomato3",                 X11.tomato3)
  , ("tomato4",                 X11.tomato4)
  , ("turquoise1",              X11.turquoise1)
  , ("turquoise2",              X11.turquoise2)
  , ("turquoise3",              X11.turquoise3)
  , ("turquoise4",              X11.turquoise4)
  , ("violetRed1",              X11.violetRed1)
  , ("violetRed2",              X11.violetRed2)
  , ("violetRed3",              X11.violetRed3)
  , ("violetRed4",              X11.violetRed4)
  , ("wheat1",                  X11.wheat1)
  , ("wheat2",                  X11.wheat2)
  , ("wheat3",                  X11.wheat3)
  , ("wheat4",                  X11.wheat4)
  , ("yellow1",                 X11.yellow1)
  , ("yellow2",                 X11.yellow2)
  , ("yellow3",                 X11.yellow3)
  , ("yellow4",                 X11.yellow4)
  , ("gray0",                   X11.gray0)
  , ("green0",                  X11.green0)
  , ("grey0",                   X11.grey0)
  , ("maroon0",                 X11.maroon0)
  , ("purple0",                 X11.purple0)
  ]




